<?php
/**
 * fred Theme Customizer
 *
 * @package fred
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fred_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'fred_customize_partial_blogname',
		));
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'fred_customize_partial_blogdescription',
		));
	}


	$wp_customize->add_panel( 'theme_options' ,array(
		'title'       => esc_html__( 'Theme Options', 'fred' ),
		'description' => ''
	));
	//----------------------------------------------------------------------------------
	// Section: Colors
	//----------------------------------------------------------------------------------
	$wp_customize->add_section( 'colors_general' , array(
   		'title'      => esc_html__('Colors', 'fred'),
        'panel'       => 'theme_options',
   		'priority'   => 1
	));
    $wp_customize->add_setting( 'theme_color', array(
        'default'        => '#ba2d2d',
        'sanitize_callback'    => 'sanitize_hex_color_no_hash',
        'sanitize_js_callback' => 'maybe_hash_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'theme_color', array(
        'label'        => esc_html__( 'Theme Color', 'fred' ),
        'section'    => 'colors_general'
    )));
	
	//----------------------------------------------------------------------------------
	// Section: General Settings
	//----------------------------------------------------------------------------------
	$wp_customize->add_section( 'general' , array(
   		'title'       => esc_html__('General Settings', 'fred'),
        'panel'       => 'theme_options',
   		'priority'    => 2
	));
	$wp_customize->add_setting('home_layout',array(
		'default'     => false,
		'sanitize_callback' => 'fred_sanitize_checkbox'
	));
	$wp_customize->add_control(new WP_Customize_Control($wp_customize,'home_layout',array(
		'label'          => esc_html__( 'Disable Sidebar on Home Page, Archive Page, Single Post', 'fred' ),
		'section'        => 'general',
		'settings'       => 'home_layout',
		'type'           => 'checkbox'
	)));
	$wp_customize->add_setting('blog_pagination',array(
		'default'     => 'pagination',
		'sanitize_callback' => 'fred_sanitize_blog_pagination'
	));
	$wp_customize->add_control(new WP_Customize_Control($wp_customize,'blog_pagination',array(
		'label'          => esc_html__('Blog Pagination or Navigation', 'fred'),
		'section'        => 'general',
		'settings'       => 'blog_pagination',
		'type'           => 'radio',
		'choices'        => array(
			'pagination'   => esc_html__('Pagination', 'fred'),
			'navigation'   => esc_html__('Navigation', 'fred')
		)
	)));
	
	//----------------------------------------------------------------------------------
	// Section: Page Settings
	//----------------------------------------------------------------------------------
	$wp_customize->add_section( 'page' , array(
   		'title'      => esc_html__('Page Settings', 'fred'),
        'panel'       => 'theme_options',
   		'priority'   => 3
	));
	$wp_customize->add_setting('page_comments',array(
		'default'     => false,
		'sanitize_callback' => 'fred_sanitize_checkbox'
	));
	$wp_customize->add_control(new WP_Customize_Control($wp_customize,'page_comments',array(
		'label'      => esc_html__('Hide Comments', 'fred'),
		'section'    => 'page',
		'settings'   => 'page_comments',
		'type'		 => 'checkbox'
	)));
	$wp_customize->add_setting('page_layout',array(
		'default'    => 'right_sidebar',
		'sanitize_callback' => 'fred_sanitize_checkbox'
	));
	$wp_customize->add_control(new WP_Customize_Control($wp_customize,'page_layout',array(
		'label'      => esc_html__( 'Disable Sidebar on Single Page', 'fred' ),
		'section'    => 'page',
		'settings'   => 'page_layout',
		'type'       => 'checkbox'
	)));
	
	//----------------------------------------------------------------------------------
	// Section: Social Media Icons 
	//----------------------------------------------------------------------------------
	$wp_customize->add_section( 'fred_social', array(
		'title'    => esc_html__( 'Social Media Icons', 'fred' ),
        'panel'       => 'theme_options',
   		'priority'   => 4
	));
	$wp_customize->add_setting( 'social_email', array(
		'default'        => '',
		'sanitize_callback' => 'sanitize_email'
	));
	$wp_customize->add_control( 'social_email', array(
		'label'        => esc_html__( 'Email Address', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_email',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_skype', array(
		'default'        => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control( 'social_skype', array(
		'label'        => esc_html__( 'Skype', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_skype',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_facebook', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_facebook', array(
		'label'        => esc_html__( 'Facebook', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_facebook',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_twitter', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_twitter', array(
		'label'        => esc_html__( 'Twitter', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_twitter',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_google_plus', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_google_plus', array(
		'label'        => esc_html__( 'Google Plus', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_google_plus',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_youtube', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_youtube', array(
		'label'        => esc_html__( 'YouTube', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_youtube',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_instagram', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_instagram', array(
		'label'        => esc_html__( 'Instagram', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_instagram',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_pinterest', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_pinterest', array(
		'label'        => esc_html__( 'Pinterest', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_pinterest',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_linkedin', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_linkedin', array(
		'label'        => esc_html__( 'LinkedIn', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_linkedin',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_tumblr', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_tumblr', array(
		'label'        => esc_html__( 'Tumblr', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_tumblr',
		'type'     => 'text'
	));
	$wp_customize->add_setting( 'social_flickr', array(
		'default'        => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( 'social_flickr', array(
		'label'        => esc_html__( 'Flickr', 'fred' ),
		'section'  => 'fred_social',
		'settings' => 'social_flickr',
		'type'     => 'text'
	));
}
add_action( 'customize_register', 'fred_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function fred_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function fred_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

function fred_sanitize_checkbox( $input ){
    if ( $input == 1 || $input == 'true' || $input === true ) {
        return 1;
    } else {
        return 0;
    }
}
function fred_sanitize_number( $number, $setting ) {
    $number = absint( $number );
    return ( $number ? $number : $setting->default );
}

function fred_sanitize_blog_pagination( $input ) {
	if ( ! in_array( $input, array( 'pagination', 'navigation' ) ) ) {
		$input = 'pagination';
	}
	return $input;
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function fred_customize_preview_js() {
	wp_enqueue_script( 'fred-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'fred_customize_preview_js' );
